#
# spec file for package gnustep-make
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         gs_config        %{_sysconfdir}/GNUstep/GNUstep.conf
%define         gs_makefiles     %{_datadir}/GNUstep/Makefiles
# Disable LTO for all GNUstep packages
%define         _lto_cflags      %{nil}
# Disable debug package as rpm > 4.13 does not allow for empty debug file list.
%global debug_package %{nil}
Name:           gnustep-make
VCS: https://src.suse.de/SLFO-pool/gnustep-make#2b582512cd97fa2d483f024d51225597a392db2c8664b9ed6ad781a423843d21
Version:        2.9.2
Release:        160000.1.4
Summary:        GNUstep Makefile package
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            http://www.gnustep.org/
Source:         https://github.com/gnustep/tools-make/releases/download/make-2_9_2/%{name}-%{version}.tar.gz
Source1:        https://github.com/gnustep/tools-make/releases/download/make-2_9_2/%{name}-%{version}.tar.gz.sig
Source2:        %{name}-rpmlintrc
Source3:        gnustep-make.keyring
BuildRequires:  gcc-objc

%description
This package contains the basic scripts, makefiles and directory
layout needed to run and compile any GNUstep software. This package
was configured for the FHS file system layout, customised for SUSE.

%prep
%autosetup

%build
# '--with-tar=tar' ensures we get the real tar rather than gnutar.
# If star is installed, it sets up a duff gnutar.
%configure --with-layout=fhs-system --with-libdir=%{_lib} \
%if 0%{?suse_version} >= 1120
  --enable-native-objc-exceptions \
%endif
  --with-tar=tar
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} \
  GNUSTEP_INSTALLATION_DOMAIN=SYSTEM \
  install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc ANNOUNCE ChangeLog FAQ NEWS README RELEASENOTES
%dir %{_sysconfdir}/GNUstep
%dir %{_datadir}/GNUstep
%{_bindir}/debugapp
%{_bindir}/gnustep-config
%{_bindir}/gnustep-tests
%{_bindir}/openapp
%{_bindir}/opentool
%{_mandir}/man1/debugapp.1%{?ext_man}
%{_mandir}/man1/gnustep-config.1%{?ext_man}
%{_mandir}/man1/gnustep-tests.1%{?ext_man}
%{_mandir}/man1/openapp.1%{?ext_man}
%{_mandir}/man1/opentool.1%{?ext_man}
%{_mandir}/man7/GNUstep.7%{?ext_man}
%{_mandir}/man7/library-combo.7%{?ext_man}
%config(noreplace) %{gs_config}
%{gs_makefiles}
%{gs_makefiles}/*.template
%{gs_makefiles}/*.*sh

%changelog
* Fri Aug  9 2024 franz.sirl-obs@lauterbach.com
- Use the --with-libdir configure option introduced with 2.9.2.
* Sun Jul  7 2024 fredkiefer@gmx.de
- Accecpted request to update to version 2.9.2
  * Update for newer versions of Java
  * Various minor bugfixes.
* Mon May 22 2023 jsrain@suse.com
- update the upstream source URLs
* Fri Jan  6 2023 fredkiefer@gmx.de
- update to version 2.9.1
  * Add workaround for Clang bug on Windows MSVC when tests contain no Objective-C constructs.
  * Various fixes for minor issues introduced in the test framework by parallelisation mof testcase execution.
* Sat Jun 25 2022 dmueller@suse.com
- update to version 2.9.0
  * Better check for objc runtime on Windows.
  * Split linker flags to better support partial linking: 'ALL_LDFLAGS'
    is now a combination of 'FINAL_LDFLAGS' and 'ALL_LDFLAGS'.
  * Better support for newer gcc versions.
  * Add support for storyboard files.
  * Increase autoconf version to 2.65 and make autoconf handle
    Objective-C++ and OBJCXX variables directly.
  * Fix bug that prevented ARC from getting used.
  * Link subproject object files directly instead of first merging them
    into 'subproject.o'.
  * Support building on Windows with Clang MSVC target.
  * Improve mingw64 support: for instance, adopt the triplet used by
    the mingw-w64 project rather than using the one returned by
    autoconf.  Fixes building Gorm.
- add keyring for source validation
* Tue Apr 14 2020 aloisio@gmx.com
- Update to version 2.8.0
  * Better library combo and ABI detection: gnustep-make will now
    attempt to detect the optimal library combo and ABI
    supported by the installed compiler and Objective-C runtime
    library. Explicit selection of the runtime ABI is now
    possible using the '--with-runtime-abi' configure option.
  * Full support for the gnustep-2.0 Objective-C ABI.
  * Support for creating a Git tag and creating a tarball from a
    git tag using the 'git-tag' and 'git-dist' targets.
  * Support for creating a Mercurial tag and creating a tarball
    from a hg tag using the 'hg-tag' and 'hg-dist' targets.
- Spec cleanup
* Sun Sep  8 2019 fredkiefer@gmx.de
- Disable LTO as this isn't working for Objective-C projects.
* Sun Apr 16 2017 fredkiefer@gmx.de
- update to 2.7.0
  o for more info please see ChangeLog file
* Fri Jan 13 2017 aloisio@gmx.com
- Added gnustep-make-rpmlintrc
- Spec cleanup
- Removed _service file and added tarball so that
  the package can be accepted into Factory
* Fri Dec 16 2016 aloisio@gmx.com
- Fixed library path for s390x
* Mon Mar 21 2016 fredkiefer@gmx.de
- update to 2.6.8
  o for more info please see ChangeLog file
* Sat May 16 2015 fredkiefer@gmx.de
- update to 2.6.7
  o for more info please see ChangeLog file
* Tue Dec 24 2013 fredkiefer@gmx.de
- update to 2.6.6
  o for more info please see ChangeLog file
* Sat Aug 10 2013 fredkiefer@gmx.de
- update to 2.6.5
  o for more info please see ChangeLog file
* Mon Apr  1 2013 fredkiefer@gmx.de
- update to 2.6.4
  o for more info please see ChangeLog file
* Mon Mar  4 2013 fredkiefer@gmx.de
- update to 2.6.3
  o for more info please see ChangeLog file
* Sat Aug  4 2012 chris@computersalat.de
- update to 2.6.2
  o for more info please see ChangeLog file
* Thu Apr  7 2011 chris@computersalat.de
- update to 2.4.0
  o for more info please see ChangeLog file
- fix fhs (library path)
  (see WindowMaker pkg: /usr/lib/GNUstep/Applications)
  o GNUSTEP_SYSTEM_APPS=/usr/lib/GNUstep/Applications
  o GNUSTEP_SYSTEM_LIBRARIES={_libdir}
- spec mods
  o add header
* Sun Apr 12 2009 lars@linux-schulserver.de
- initial version
